pub struct PreparedDownloadDirectories {
pub hub_cache: PathBuf,
pub xet_cache: PathBuf,
pub fallbacks: Vec<DownloadDirectoryFallback>,
}Fields
hub_cache: PathBufxet_cache: PathBuffallbacks: Vec<DownloadDirectoryFallback>Implementations
Sourceimpl PreparedDownloadDirectories
impl PreparedDownloadDirectories
Sourcepub unsafe fn apply_to_process_environment(&self)
pub unsafe fn apply_to_process_environment(&self)
Apply the validated directories to the process environment.
Safety
The caller must guarantee that no other threads are reading or writing process environment variables. The shipped binary calls this before it constructs its Tokio runtime.